@@ -11,6 +11,7 @@ class DatasetPreprocess:
     validation_length: int
     test_length: Optional[int] = None
     unlabeled_length: Optional[int] = None
+    additional_length: Optional[int] = None
 
 
 @dataclass
@@ -122,9 +123,16 @@ class BoundingBox:
 
 
 
+@dataclass
+class LeapAnalysisConfiguration:
+    domain_gap_metadata: Optional[List[str]] = None
+    feature_flags: Optional[List[str]] = None
+
+
 @dataclass
 class EngineFileContract:
     node_connections: Optional[List[NodeConnection]] = None
+    leap_analysis_configuration: Optional[LeapAnalysisConfiguration] = None
 
 
 @dataclass
