@@ -1,3 +1,4 @@
+
 import inspect
 from typing import Callable, List, Optional, Dict, Any, Type, Union
 
@@ -11,10 +12,10 @@ from code_loader.contract.datasetclasses import SectionCallableInterface, InputH
     CustomCallableInterfaceMultiArgs, ConfusionMatrixCallableInterfaceMultiArgs, LeapData, \
     CustomMultipleReturnCallableInterfaceMultiArgs, DatasetBaseHandler, custom_latent_space_attribute, \
     RawInputsForHeatmap, VisualizerHandlerData, MetricHandlerData, CustomLossHandlerData, SamplePreprocessResponse, \
-    ElementInstanceMasksHandler, InstanceCallableInterface
+    ElementInstanceMasksHandler, InstanceCallableInterface, CustomLatentSpaceHandler
 from code_loader.contract.enums import LeapDataType, DataStateEnum, DataStateType, MetricDirection, DatasetMetadataType
 from code_loader.contract.mapping import NodeConnection, NodeMapping, NodeMappingType
-from code_loader.contract.responsedataclasses import DatasetTestResultPayload
+from code_loader.contract.responsedataclasses import DatasetTestResultPayload, LeapAnalysisConfiguration
 from code_loader.contract.visualizer_classes import map_leap_data_type_to_visualizer_class
 from code_loader.default_losses import loss_name_to_function
 from code_loader.default_metrics import metrics_names_to_functions_and_direction
@@ -25,6 +26,11 @@ from code_loader.visualizers.default_visualizers import DefaultVisualizer, \
     default_image_mask_visualizer, default_text_mask_visualizer, default_raw_data_visualizer, default_video_visualizer
 
 
+mapping_runtime_mode_env_var_mame = '__MAPPING_RUNTIME_MODE__'
+
+
+
+
 class LeapBinder:
     """
     Interface to the Tensorleap platform. Provides methods to set up preprocessing,
@@ -46,8 +52,10 @@ class LeapBinder:
         self._extend_with_default_losses()
 
         self.mapping_connections: List[NodeConnection] = []
+        self.integration_test_func: Optional[Callable[[str, PreprocessResponse], Any]] = None
 
         self.batch_size_to_validate: Optional[int] = None
+        self.leap_analysis_configuration = LeapAnalysisConfiguration()
 
     def _extend_with_default_visualizers(self) -> None:
         self.set_visualizer(function=default_image_visualizer, name=DefaultVisualizer.Image.value,
@@ -417,6 +425,19 @@ class LeapBinder:
         """
         self.setup_container.metadata.append(MetadataHandler(name, function, metadata_type))
 
+    def set_custom_latent_space(self, function: SectionCallableInterface) -> None:
+        """
+        Set a custom latent space function.
+
+        Args:
+        function (SectionCallableInterface): The metadata handler function.
+            This function receives:
+                subset (PreprocessResponse): The subset of the data.
+                index (int): The index of the sample within the subset.
+            This function should numpy float32 array contains the latent space vec of the sample.
+        """
+        self.setup_container.custom_latent_space = CustomLatentSpaceHandler(function)
+
     def set_custom_layer(self, custom_layer: Type[Any], name: str, inspect_layer: bool = False,
                          kernel_index: Optional[int] = None, use_custom_latent_space: bool = False) -> None:
         """
